/*************** CONFIGURATION START ***************/
const CONFIG = {
    SITE_NAME: "Pantry Peek",
    LOGO_PATH: "https://rukminim2.flixcart.com/image/850/1000/name-plate/u/m/v/sspl01-shreyas-signages-multicolor-original-imaekd6kf7gaqdgg.jpeg?q=90&crop=false",
    POSTS_PER_PAGE: 10,
    RECENT_POSTS_SIDEBAR: 5,
    SUPABASE: {
        URL: "https://pjbgaichoislenvkfqkr.supabase.co",
        KEY: "eyJhbGciOiJIUzI1NiIsInR5cCI6IkpXVCJ9.eyJpc3MiOiJzdXBhYmFzZSIsInJlZiI6InBqYmdhaWNob2lzbGVudmtmcWtyIiwicm9sZSI6ImFub24iLCJpYXQiOjE3MzgwNzM2NjgsImV4cCI6MjA1MzY0OTY2OH0.O6-6Nape4lxGc6b_4CMJX846cKKp9UkFqUpoZLHc2hk",
        TABLE: "articles"
    },
    POST_TEMPLATE: "post.html"
};
/*************** CONFIGURATION END ***************/

$(document).ready(function() {
    // Set initial title
    document.title = CONFIG.SITE_NAME;
    $('#site-name').text(CONFIG.SITE_NAME);
    $('#site-logo').attr('src', CONFIG.LOGO_PATH);
    handleRoute();
    window.addEventListener('popstate', handleRoute);
});

function ensureHashRouting() {
    const path = window.location.pathname;
    
    // Only fix if not on homepage and hash is missing
    if (path !== '/' && !window.location.hash) {
        const newPath = `#/${path.slice(1)}`;
        history.replaceState(null, null, newPath);
    }
}

// Routing
function handleRoute() {
    ensureHashRouting();
    const hashPath = window.location.hash.substring(2) || '/';
    
    // Reset title to default first
    document.title = CONFIG.SITE_NAME;
    
    if (hashPath === '/') {
        loadHomePage();
    } else {
        loadPostPage(hashPath);
    }
}

async function loadPostFromURL() {
    const urlParams = new URLSearchParams(window.location.search);
    const postPath = urlParams.get('path');
    
    if (!postPath) {
        window.location.href = '/';
        return;
    }

    const posts = await fetchPosts({
        filter: `post_path=eq.${postPath}`
    });

    if (posts.length > 0) {
        renderPostPage(posts[0]);
    } else {
        window.location.href = '/';
    }
}

// Homepage loader
async function loadHomePage() {
    const page = new URLSearchParams(window.location.search).get('page') || 1;
    const posts = await fetchPosts({
        limit: CONFIG.POSTS_PER_PAGE,
        offset: (page - 1) * CONFIG.POSTS_PER_PAGE
    });

    renderHomepage(posts, page);
}

// Single post loader
async function loadPostPage(path) {
    const decodedPath = decodeURIComponent(path);
    const posts = await fetchPosts({
        filter: `post_path=eq.${decodedPath}`
    });
    
    if (posts.length > 0) {
        renderPostPage(posts[0]);
    } else {
        window.location.href = '/';
    }
}

// Supabase fetch helper
async function fetchPosts({ limit, offset, filter }) {
    let url = `${CONFIG.SUPABASE.URL}/rest/v1/${CONFIG.SUPABASE.TABLE}?`;
    
    // Add filters if present
    if (filter) url += `${filter}&`;
    if (limit) url += `limit=${limit}&`;
    if (offset) url += `offset=${offset}&`;
    
    // Always sort by latest first
    url += `order=date.desc`;

    try {
        const response = await fetch(url, {
            headers: {
                'apikey': CONFIG.SUPABASE.KEY,
                'Accept': 'application/json'
            }
        });
        
        if (!response.ok) throw new Error('Request failed');
        return await response.json();
    } catch (error) {
        console.error('Error fetching posts:', error);
        return [];
    }
}

//recent post on the side
async function loadRecentPosts() {
    const posts = await fetchPosts({
        limit: CONFIG.RECENT_POSTS_SIDEBAR
    });
    
    let html = '';
    posts.forEach(post => {
        html += `
            <div class="recent-post">
                <a href="#/${encodeURIComponent(post.post_path)}">${post.post_title}</a>
            </div>
        `;
    });
    
    $('.recent-posts').html(html);
}

function renderHomepage(posts, currentPage) {
    let html = '<div class="posts-list">';
    
    posts.forEach(post => {
        html += `
            <article class="post-card">
                <img src="${post.image_path}" alt="${post.post_title}" class="post-thumbnail">
                <div class="post-content">
                    <h2><a href="#/${encodeURIComponent(post.post_path)}">${post.post_title}</a></h2>
                    <p>${post.post_content.substring(0, 100)}...</p>
                    <a href="#/${encodeURIComponent(post.post_path)}" class="read-more">Read more</a>
                </div>
            </article>
        `;
    });
    
    html += '</div>';
    $('#content').html(html);
}

function renderPostPage(post) {

    document.title = `${post.post_title} | ${CONFIG.SITE_NAME}`;

    let html = `
        <div class="post-container">
            <article class="main-post">
                <h1>${post.post_title}</h1>
                <img src="${post.image_path}" alt="${post.post_title}" class="post-image">
                <div class="post-content">${post.post_content}</div>
            </article>
            
            <aside class="sidebar">
                <h3>Recent Posts</h3>
                <div class="recent-posts"></div>
            </aside>
        </div>
    `;
    
    $('#content').html(html);
    loadRecentPosts();
}

// Initialize
$(document).ready(function() {
    $('#site-name').text(CONFIG.SITE_NAME);
    $('#site-logo').attr('src', CONFIG.LOGO_PATH);
    handleRoute();
    window.addEventListener('popstate', handleRoute);
});